==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>打开方式...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>首选</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>可用程序</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>二进制文件位置</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>设置该应用程序为默认 </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>（电子邮件链接）</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(网址 URL - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>多媒体</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>图像</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>科学</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>其他</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation>[默认] </translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>寻找二进制应用程序</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>File Error</source>
        <translation>文件错误</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>音频音量 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>屏幕亮度 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>无效的文件或网址：%1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation>应用程序输入无效: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>应用程序快捷方式缺少启动信息（错误的快捷方式）：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>网址快捷方式缺少网址 : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>目录的快捷方式是丢失目录的路径 : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>未知类型的快捷方式：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Binary Missing</source>
        <translation>二进制文件丢失</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>无法找到 “%1”。请确认它已被安装。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>Application Error</source>
        <translation>应用程序出错</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="421"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>下面的应用程序遇到错误，需要关闭:</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/core/lumina-open/i18n/lumina-open_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>打开方式...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>首选</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>可用程序</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>二进制文件位置</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>设置该应用程序为默认 </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>（电子邮件链接）</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(网址 URL - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>多媒体</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>图像</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>科学</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>工具</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>其他</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="211"/>
        <source>[default] </source>
        <translation>[默认] </translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="278"/>
        <source>Find Application Binary</source>
        <translation>寻找二进制应用程序</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>File Error</source>
        <translation>文件错误</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="191"/>
        <location filename="../main.cpp" line="197"/>
        <source>Audio Volume %1%</source>
        <translation>音频音量 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="205"/>
        <location filename="../main.cpp" line="214"/>
        <source>Screen Brightness %1%</source>
        <translation>屏幕亮度 %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <source>Invalid file or URL: %1</source>
        <translation>无效的文件或网址：%1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="267"/>
        <source>Application entry is invalid: %1</source>
        <translation>应用程序输入无效: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="278"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>应用程序快捷方式缺少启动信息（错误的快捷方式）：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="291"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>网址快捷方式缺少网址 : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="302"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>目录的快捷方式是丢失目录的路径 : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="307"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>未知类型的快捷方式：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="370"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>无法找到 “%1”。请确认它已被安装。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>Application Error</source>
        <translation>应用程序出错</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="419"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>下面的应用程序遇到错误，需要关闭:</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished">多媒体</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished">开发</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished">教育</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished">图像</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished">网络</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished">办公</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished">科学</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">设置</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished">系统</translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
